@@ -155,7 +155,6 @@ private:
 
 #ifndef GLOM_ENABLE_MAEMO
   virtual void init_menus_file(); //override.
-  virtual void init_menus_help(); //override
 #endif //GLOM_ENABLE_MAEMO
 
   bool offer_new_or_existing();
@@ -173,8 +172,8 @@ private:
   void existing_or_new_new();
 
   void on_menu_file_toggle_share();
-  void on_menu_userlevel_developer();
-  void on_menu_userlevel_operator();
+  void on_menu_developer_developer();
+  void on_menu_developer_operator();
   void on_menu_file_save_as_example();
   void on_menu_developer_changelanguage();
   void on_menu_developer_translations();
@@ -202,6 +201,9 @@ private:
   void on_connection_avahi_done();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  void on_menu_help_about();
+  void on_about_close();
+
 #ifndef G_OS_WIN32
   /** Offer a file chooser dialog, with a Browse Network button.
    * @param browsed This will be set to true if the user chose a networked glom instance to open.
@@ -236,7 +238,7 @@ private:
   Glib::RefPtr<Gtk::Action> m_action_mode_find;
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Glib::RefPtr<Gtk::Action> m_action_developer_users;
-  Glib::RefPtr<Gtk::RadioAction> m_action_menu_userlevel_developer, m_action_menu_userlevel_operator;
+  Glib::RefPtr<Gtk::RadioAction> m_action_menu_developer_developer, m_action_menu_developer_operator;
   Glib::RefPtr<Gtk::ToggleAction> m_action_show_layout_toolbar;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -253,12 +255,16 @@ private:
   Gtk::VBox* m_pBoxTop;
   Gtk::VBox* m_pBoxSidebar;
   Frame_Glom* m_pFrame;
+  
+  bool m_bAboutShown;
+  Gtk::AboutDialog* m_pAbout; //About box.
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   Window_Translations* m_window_translations;
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
+  Glib::RefPtr<Gtk::ActionGroup> m_refHelpActionGroup;
   Glib::RefPtr<Gtk::ActionGroup> m_refNavTablesActionGroup, m_refNavReportsActionGroup, m_refNavPrintLayoutsActionGroup;
   type_listActions m_listNavTableActions, m_listNavReportActions, m_listNavPrintLayoutActions;
   Gtk::UIManager::ui_merge_id m_menu_tables_ui_merge_id, m_menu_reports_ui_merge_id, m_menu_print_layouts_ui_merge_id;
@@ -278,7 +284,6 @@ private:
   Dialog_ProgressCreating* m_dialog_progress_creating;
   Dialog_ProgressCreating* m_dialog_progess_save_backup;
   Dialog_ProgressCreating* m_dialog_progess_convert_backup;
-
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   // This is set to the URI of an example file that is loaded to be able to
