@@ -99,13 +99,11 @@ protected:
    */
   virtual bool supports_remote_access() const = 0;
 
-  /** The operator to use to compare strings in a case-independant way. This
-   * is backend-depandent. For example, postgres uses ILIKE but SQLite uses
+  /** The operator to use to compare strings in a case-insensitive way. This
+   * is backend-dependent. For example, postgres uses ILIKE but SQLite uses
    * LIKE.
-   * TODO: Maybe we can use libgda to construct the expression, so we don't
-   * need this function.
    */
-  virtual Glib::ustring get_string_find_operator() const = 0;
+  virtual Gnome::Gda::SqlOperatorType get_string_find_operator() const = 0;
 
   /** This specifies the database schema which contains the non-internal
    * tables. This is used to speedup the libgda meta store update by only
