@@ -59,8 +59,11 @@ void Label::init()
   add(m_label);
   m_label.show();
   set_events(Gdk::ALL_EVENTS_MASK);
-  //This would be more efficient if we were only using the (base) EventBox to get events, 
+  //This would be more efficient if we were only using the (base) EventBox to get events,
   //but we also want to allow changing of the background color, so we don't use it: set_visible_window(false);
+
+  //Otherwise the label could demand a huge width if there is lots of text.
+  m_label.set_line_wrap();
 }
 
 Application* Label::get_application()
