@@ -103,7 +103,7 @@ DbAddDel::DbAddDel()
   m_TreeView.show();
 
   //Make sure that the TreeView doesn't start out only big enough for zero items.
-  m_TreeView.set_size_request(-1, 150);
+  set_height_rows(5);
 
   //Allow the user to change the column order:
   //m_TreeView.set_column_drag_function( sigc::mem_fun(*this, &DbAddDel::on_treeview_column_drop) );
@@ -146,6 +146,15 @@ DbAddDel::~DbAddDel()
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
+void DbAddDel::set_height_rows(guint rows)
+{
+  //TODO: File a bug about API for this in GtkTreeView.
+  const guint height_for_rows = rows * get_fixed_cell_height();
+  //std::cout << "debug: height_for_rows = " << height_for_rows << std::endl;
+  const guint extra_for_treeview = 50; //TODO: Find some way to guess this.
+  m_ScrolledWindow.set_min_content_height(height_for_rows + extra_for_treeview);
+}
+
 void DbAddDel::do_user_requested_edit()
 {
   Gtk::TreeModel::iterator iter = get_item_selected();
@@ -554,8 +563,7 @@ guint DbAddDel::get_count() const
   //Take account of the extra blank for new entries:
   if(get_allow_user_actions()) //If it has the extra row.
   {
-    if(get_is_placeholder_row(get_last_row()))
-      --iCount;
+    --iCount;
   }
 
   return iCount;
@@ -597,7 +605,7 @@ guint DbAddDel::get_columns_count() const
   #endif //GLOM_ENABLE_MAEMO
 }
 
-int DbAddDel::get_fixed_cell_height()
+guint DbAddDel::get_fixed_cell_height()
 {
   if(m_fixed_cell_height <= 0)
   {
@@ -636,8 +644,8 @@ int DbAddDel::get_fixed_cell_height()
       int height = 0;
       refLayout->get_pixel_size(width, height);
 
-      if(height > m_fixed_cell_height)
-        m_fixed_cell_height = height;
+      if(height > (int)m_fixed_cell_height)
+        m_fixed_cell_height = (guint)height;
     }
   }
   
@@ -1942,11 +1950,6 @@ bool DbAddDel::get_is_placeholder_row(const Gtk::TreeModel::iterator& iter) cons
 {
   //g_warning("DbAddDel::get_is_placeholder_row()");
 
-  if(!get_is_last_row(iter))
-  {
-    return false;
-  }
-
   if(!iter)
     return false;
 
