@@ -225,7 +225,7 @@ void Dialog_GroupsList::on_button_group_delete()
           const Glib::ustring strQuery = "DROP GROUP \"" + group + "\"";
           const bool test = DbUtils::query_execute_string(strQuery);
           if(!test)
-            std::cerr << "Box_DB_Table_Definition::on_adddel_delete(): DROP GROUP failed." << std::endl;
+            std::cerr << G_STRFUNC << ": DROP GROUP failed." << std::endl;
 
           fill_group_list();
         }
@@ -240,6 +240,9 @@ void Dialog_GroupsList::on_button_group_new()
 {
   Dialog_NewGroup* dialog = 0;
   Utils::get_glade_widget_derived_with_warning(dialog);
+  if(!dialog) //Unlikely and it already warns on stderr.
+    return;
+    
   dialog->set_transient_for(*this);
   const int response = Glom::Utils::dialog_run_with_help(dialog);
 
@@ -255,7 +258,7 @@ void Dialog_GroupsList::on_button_group_new()
     const Glib::ustring strQuery = "CREATE GROUP \"" + group_name + "\"";
     const bool test = DbUtils::query_execute_string(strQuery);
     if(!test)
-      std::cout << "Dialog_GroupsList::on_button_group_new(): CREATE GROUP failed." << std::endl;
+      std::cout << "debug: " << G_STRFUNC << ": CREATE GROUP failed." << std::endl;
 
     //Give the new group some sensible default privileges:
     Privileges priv;
@@ -291,6 +294,9 @@ void Dialog_GroupsList::on_button_group_users()
 
       Dialog_UsersList* dialog = 0;
       Utils::get_glade_widget_derived_with_warning(dialog);
+      if(!dialog) //Unlikely and it already warns on stderr.
+        return;
+    
       dialog->set_transient_for(*this);
       add_view(dialog); //Give it access to the document.
 
@@ -483,7 +489,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   const bool test = DbUtils::query_execute_string(strQuery); //TODO: Handle errors.
   if(!test)
-    std::cerr << "Dialog_GroupsList::set_table_privilege(): GRANT/REVOKE failed." << std::endl;
+    std::cerr << G_STRFUNC << ": GRANT/REVOKE failed." << std::endl;
 
   return test;
 }
