@@ -106,7 +106,8 @@ sharedptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 
   //Page Setup:
   Glib::KeyFile key_file;
-  m_page_setup->save_to_key_file(key_file);
+  if(m_page_setup)
+    m_page_setup->save_to_key_file(key_file);
 
   Glib::ustring data;
   //TODO: Catch an exception
@@ -782,11 +783,6 @@ void Canvas_PrintLayout::set_zoom_percent(guint percent)
   set_scale(scale);
 }
 
-guint Canvas_PrintLayout::get_zoom_percent() const
-{
-  return (guint)(get_scale() * (double)100);
-}
-
 void Canvas_PrintLayout::hide_page_bounds()
 {
   m_bounds_group->property_visibility() = Goocanvas::ITEM_HIDDEN;
