@@ -32,8 +32,12 @@
 namespace Glom
 {
 
+ImageGlom::type_vec_ustrings ImageGlom::m_evince_supported_mime_types;
+ImageGlom::type_vec_ustrings ImageGlom::m_gdkpixbuf_supported_mime_types;
+
 ImageGlom::ImageGlom()
-: m_image(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG), //The widget is invisible if we don't specify an image.
+: m_ev_view(0),
+  m_ev_document_model(0),
   m_pMenuPopup_UserMode(0)
 {
   init();
@@ -41,7 +45,8 @@ ImageGlom::ImageGlom()
 
 ImageGlom::ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::EventBox(cobject),
-  m_image(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG), //The widget is invisible if we don't specify an image.
+  m_ev_view(0),
+  m_ev_document_model(0),
   m_pMenuPopup_UserMode(0)
 {
   init();
@@ -49,6 +54,16 @@ ImageGlom::ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>&
 
 void ImageGlom::init()
 {
+  m_ev_view = EV_VIEW(ev_view_new());
+  //gtk_widget_add_events(GTK_WIDGET(m_ev_view), GDK_BUTTON_PRESS_MASK);
+
+  //Connect the the EvView's button-press-event signal, 
+  //because we don't get it otherwise.
+  //For some reason this is not necessary with the GtkImage.
+  Gtk::Widget* cppEvView = Glib::wrap(GTK_WIDGET(m_ev_view));
+  cppEvView->signal_button_press_event().connect(
+    sigc::mem_fun(*this, &ImageGlom::on_button_press_event), false);
+
   m_read_only = false;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -58,10 +73,9 @@ void ImageGlom::init()
   setup_menu_usermode();
 
   //m_image.set_size_request(150, 150);
-  m_image.show();
+
 
   m_frame.set_shadow_type(Gtk::SHADOW_ETCHED_IN); //Without this, the image widget has no borders and is completely invisible when empty.
-  m_frame.add(m_image);
   m_frame.show();
 
   add(m_frame);
@@ -149,179 +163,336 @@ bool ImageGlom::get_has_original_data() const
   return true; //TODO.
 }
 
+/*
 void ImageGlom::set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf)
 {
   m_pixbuf_original = pixbuf;
-  scale();
+  show_image_data();
 }
+*/
 
 void ImageGlom::set_value(const Gnome::Gda::Value& value)
 {
   // Remember original data 
   m_original_data = Gnome::Gda::Value();
   m_original_data = value;
-  Glib::RefPtr<Gdk::Pixbuf> pixbuf = Utils::get_pixbuf_for_gda_value(value);
-
-  if(pixbuf)
-  {
-    scale();
-    set_pixbuf(pixbuf);
-  }
-  else
-  {
-    /*
-    std::cout << "Debug: Setting MISSING_IMAGE" << std::endl;
-    
-    //Check that this stock icon size is really available,
-    //though it would be a distro error if it is not.
-    Glib::RefPtr<Gtk::Style> style = get_style();
-    if(style)
-    {
-      /std::cout << "Debug: Setting MISSING_IMAGE 3" << std::endl;
-
-      const Gtk::IconSet iconset = style->lookup_icon_set(Gtk::Stock::MISSING_IMAGE);
-
-      std::cout << "Debug: Setting MISSING_IMAGE 4" << std::endl;
-
-      typedef std::vector<Gtk::IconSize> type_vecSizes;
-      type_vecSizes sizes = iconset.get_sizes();
-      type_vecSizes::iterator iterFind = std::find(sizes.begin(), sizes.end(), Gtk::ICON_SIZE_DIALOG);
-      if(iterFind != sizes.end())
-      {
-     */
-        m_image.set(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
-     /*
-      }
-      else
-      {
-        std::cerr << "Glom: The current theme does not seem to havae the Gtk::Stock::MISSING_IMAGE icon in size Gtk::ICON_SIZE_DIALOG" << std::endl;
-
-        if(!sizes.empty() && (sizes[0] > 0))
-        {
-          std::cerr << "  Using alternative stock icon size." << std::endl;
-          m_image.set(Gtk::Stock::MISSING_IMAGE, sizes[0]);
-        }
-        else
-        {
-          std::cerr << "  No alternative stock icon size available either, for this stock icon." << std::endl;
-          m_image.set("");
-        }
-      }
-    }
-    else
-    {
-      std::cerr << "Glom: No Gtk::Style available for this widget (yet), so not setting MISSING_IMAGE icon." << std::endl;
-      m_image.set("");
-    }
-    */
-
-    m_pixbuf_original = Glib::RefPtr<Gdk::Pixbuf>();
-  }
+  show_image_data();
 }
 
 Gnome::Gda::Value ImageGlom::get_value() const
 {
-  //TODO: Return the data from the file that was just chosen.
-  //Don't store the original here any longer than necessary,
-  if(m_original_data.get_value_type() != G_TYPE_NONE)
-    return m_original_data;
-  
+  return m_original_data;
+}
+
+void ImageGlom::on_size_allocate(Gtk::Allocation& allocation)
+{
+  Gtk::EventBox::on_size_allocate(allocation);
+
+  //Resize the GtkImage if necessary:
   if(m_pixbuf_original)
   {
-    try
-    {
-      gchar* buffer = 0;
-      gsize buffer_size = 0;
-      std::vector<Glib::ustring> list_keys;
-      std::vector<Glib::ustring> list_values;
-      //list_keys.push_back("quality"); //For jpeg only.
-      //list_values.push_back("95");
+    const Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = get_scaled_image();
+    m_image.set(pixbuf_scaled);
+  }
+}
 
-      m_pixbuf_original->save_to_buffer(buffer, buffer_size, GLOM_IMAGE_FORMAT, list_keys, list_values); //Always store images as the standard format in the database.
+static void image_glom_ev_job_finished(EvJob* job, void* user_data)
+{
+  g_assert(job);
+  
+  ImageGlom* self = (ImageGlom*)user_data;
+  g_assert(self);
+  
+  self->on_ev_job_finished(job);
+}
+  
+void ImageGlom::on_ev_job_finished(EvJob* job)
+{
+	if (ev_job_is_failed (job)) {
+		g_warning ("%s", job->error->message);
+		g_object_unref (job);
 
-      //g_warning("ImageGlom::get_value(): debug: to db: ");
-      //for(int i = 0; i < 10; ++i)
-      //  g_warning("%02X (%c), ", (guint8)buffer[i], buffer[i]);
+		return;
+	}
 
-      GdaBinary* bin = g_new(GdaBinary, 1);
-      bin->data = reinterpret_cast<guchar*>(buffer);
-      bin->binary_length = buffer_size;
+	ev_document_model_set_document(m_ev_document_model, job->document);
+	ev_document_model_set_page(m_ev_document_model, 1);
+	g_object_unref (job);
+	
+	ev_view_set_loading(m_ev_view, FALSE);
+}
 
-      m_original_data = Gnome::Gda::Value();
-      m_original_data.Glib::ValueBase::init(GDA_TYPE_BINARY);
-      gda_value_take_binary(m_original_data.gobj(), bin);
+Glib::ustring ImageGlom::get_mime_type() const
+{
+  const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+  if(!gda_binary)
+    return Glib::ustring();
+    
+  if(!gda_binary->data)
+    return Glib::ustring();
 
-      buffer = 0;
-      return m_original_data;
-    }
-    catch(const Glib::Exception& ex)
-    {
-      std::cerr << G_STRFUNC << ": " << ex.what() << std::endl;
-    }
+  bool uncertain = false;
+  const Glib::ustring result = Gio::content_type_guess(std::string(),
+    gda_binary->data, gda_binary->binary_length,
+    uncertain);
+
+  //std::cout << G_STRFUNC << ": mime_type=" << result << ", uncertain=" << uncertain << std::endl;
+  return result;  
+}
+
+void ImageGlom::fill_evince_supported_mime_types()
+{
+  //Fill the static list if it has not already been filled:
+  if(!m_evince_supported_mime_types.empty())
+    return;
+
+  //Discover what mime types libevview can support.
+  //Older versions supported image types too, via GdkPixbuf,
+  //but that support was then removed.  
+  GList* types_list = ev_backends_manager_get_all_types_info();
+  if(!types_list)
+  {
+    return;
+  }
+  
+  for(GList* l = types_list; l; l = g_list_next(l))
+  {
+	  EvTypeInfo *info = (EvTypeInfo *)l->data;
+	  if(!info)
+	    continue;
+
+	  const char* mime_type = 0;
+	  int i = 0;
+	  while((mime_type = info->mime_types[i++]))
+	  {
+	    if(mime_type)
+	      m_evince_supported_mime_types.push_back(mime_type);
+	    //std::cout << "evince supported mime_type=" << mime_type << std::endl; 
+	  }
+	}  
+}
+
+void ImageGlom::fill_gdkpixbuf_supported_mime_types()
+{
+  //Fill the static list if it has not already been filled:
+  if(!m_gdkpixbuf_supported_mime_types.empty())
+    return;
+    
+  typedef std::vector<Gdk::PixbufFormat> type_vec_formats;
+  const type_vec_formats formats = Gdk::Pixbuf::get_formats();
+  
+  for(type_vec_formats::const_iterator iter = formats.begin();
+    iter != formats.end(); ++iter)
+  {
+    const Gdk::PixbufFormat& format = *iter;
+    const std::vector<Glib::ustring> mime_types = format.get_mime_types();
+    m_gdkpixbuf_supported_mime_types.insert(
+      m_gdkpixbuf_supported_mime_types.end(),
+      mime_types.begin(), mime_types.end());
+  }
+}
+
+void ImageGlom::show_image_data()
+{
+  bool use_evince = false;
+  
+  const Glib::ustring mime_type = get_mime_type();
+
+  //std::cout << "mime_type=" << mime_type << std::endl; 
+  
+  fill_evince_supported_mime_types();
+  const type_vec_ustrings::iterator iterFind = 
+    std::find(m_evince_supported_mime_types.begin(),
+      m_evince_supported_mime_types.end(),
+      mime_type);
+  if(iterFind != m_evince_supported_mime_types.end())
+  {
+    use_evince = true;
+  }  
+  
+  m_frame.remove();
+    
+  //Clear all possible display widgets:
+  m_pixbuf_original.reset();
+  m_pixbuf_thumbnail.reset();
+  m_image.set(Glib::RefPtr<Gdk::Pixbuf>()); //TODO: Add an unset() to gtkmm.
+  
+  if(m_ev_document_model)
+  {
+    g_object_unref(m_ev_document_model);
+    m_ev_document_model = 0;
   }
 
-  return Gnome::Gda::Value();
-}
-
-bool ImageGlom::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
-{
-  const bool result = Gtk::EventBox::on_draw(cr);
-
-  scale();
-  return result;
-}
-
-void ImageGlom::scale()
-{
-  Glib::RefPtr<Gdk::Pixbuf> pixbuf = m_pixbuf_original;
-
-  if(pixbuf)
+  if(use_evince)
   {
-    const Gtk::Allocation allocation = m_image.get_allocation();
-    const int pixbuf_height = pixbuf->get_height();
-    const int pixbuf_width = pixbuf->get_width();
+    //Use EvView:
+    m_image.hide();
     
-    int allocation_height = allocation.get_height();
-    int allocation_width = allocation.get_width();
-    
-    //If the Image widget has expanded to be big enough for the original image,
-    //it might be huge. We don't want that.
-    //Scaling it down will reduce how much it requests.
-    if(allocation_width >= 400)
-      allocation_width = 400;
-      
-    if(allocation_height >= 400)
-      allocation_height = 400;
-      
-    //std::cout << "pixbuf_height=" << pixbuf_height << ", pixbuf_width=" << pixbuf_width << std::endl;
-    //std::cout << "allocation_height=" << allocation.get_height() << ", allocation_width=" << allocation.get_width() << std::endl;
+    gtk_widget_show(GTK_WIDGET(m_ev_view));
+    gtk_container_add(GTK_CONTAINER(m_frame.gobj()), GTK_WIDGET(m_ev_view));
 
-    if( (pixbuf_height >allocation_height ) ||
-        (pixbuf_width > allocation_width) )
+    const Glib::ustring uri = save_to_temp_file(false /* don't show progress */);
+    if(uri.empty())
     {
-      if(allocation_height > 10 || allocation_width > 10)
+      std::cerr << G_STRFUNC << "Could not save temp file to show in the EvView." << std::endl;
+    }
+  
+    EvJob *job = ev_job_load_new(uri.c_str());
+  
+    m_ev_document_model = ev_document_model_new();
+    ev_view_set_model(m_ev_view, m_ev_document_model);
+	  ev_document_model_set_continuous(m_ev_document_model, FALSE); //Show only one page.
+	  ev_view_set_loading(m_ev_view, TRUE);
+	
+    g_signal_connect (job, "finished",
+		  G_CALLBACK (image_glom_ev_job_finished), this);
+	  ev_job_scheduler_push_job (job, EV_JOB_PRIORITY_NONE);
+  }
+  else
+  {
+    //Use GtkImage instead:
+    gtk_widget_hide(GTK_WIDGET(m_ev_view));  
+    m_image.show();
+    m_frame.add(m_image);
+    
+    Glib::RefPtr<const Gio::Icon> icon;
+      
+    bool use_gdkpixbuf = false;
+    fill_gdkpixbuf_supported_mime_types();
+    const type_vec_ustrings::iterator iterFind = 
+      std::find(m_gdkpixbuf_supported_mime_types.begin(),
+        m_gdkpixbuf_supported_mime_types.end(),
+        mime_type);
+    if(iterFind != m_gdkpixbuf_supported_mime_types.end())
+    {
+      use_gdkpixbuf = true;
+    }
+    
+    if(use_gdkpixbuf)
+    {
+      //Try to use GdkPixbuf's loader:
+      m_pixbuf_original = Utils::get_pixbuf_for_gda_value(m_original_data);
+    }
+    else
+    {
+      //Try to use a thumbnail via GFile:
+      //TODO: Do this asynchronously:
+      const Glib::ustring uri = save_to_temp_file(false /* don't show progress */);
+      if(uri.empty())
       {
-        Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = Utils::image_scale_keeping_ratio(pixbuf, allocation.get_height(), allocation.get_width());
-        if(!pixbuf_scaled)
+        std::cerr << G_STRFUNC << "Could not save temp file to get a thumbnail." << std::endl;
+      }
+      else
+      {
+        Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+        Glib::RefPtr<const Gio::FileInfo> file_info;
+
+        try
         {
-          std::cerr << "Utils::image_scale_keeping_ratio() returned NULL pixbuf." << std::endl;
+          file_info = file->query_info(
+            G_FILE_ATTRIBUTE_THUMBNAIL_PATH ","
+            G_FILE_ATTRIBUTE_THUMBNAILING_FAILED ","
+            G_FILE_ATTRIBUTE_STANDARD_ICON);
         }
-        else 
+        catch(const Glib::Error& ex)
         {
-          //Don't set a new pixbuf if the dimensions have not changed:
-          Glib::RefPtr<const Gdk::Pixbuf> pixbuf_in_image;
-
-          if(m_image.get_storage_type() == Gtk::IMAGE_PIXBUF) //Prevent warning.
-            pixbuf_in_image = m_image.get_pixbuf();
-
-          if( !pixbuf_in_image || (pixbuf_in_image->get_height() != pixbuf_scaled->get_height()) || (pixbuf_in_image->get_width() != pixbuf_scaled->get_width()) )
-            m_image.set(pixbuf_scaled);
+          std::cerr << G_STRFUNC << ": query_info() failed: " << ex.what() << std::endl;
+        }
+      
+        if(file_info)
+        {
+          const std::string filepath = 
+            file_info->get_attribute_byte_string(G_FILE_ATTRIBUTE_THUMBNAIL_PATH);
+          const bool failed = 
+            file_info->get_attribute_boolean(G_FILE_ATTRIBUTE_THUMBNAILING_FAILED);
+          if(!filepath.empty())
+            m_pixbuf_original = Gdk::Pixbuf::create_from_file(filepath);
+          else
+          {
+            std::cerr << G_STRFUNC << ": Could not get attribute G_FILE_ATTRIBUTE_THUMBNAIL_PATH. failed=" << failed << std::endl;
+            
+            //Use the standard icon instead:
+            icon = file_info->get_icon();
+            if(!icon)
+            {
+               std::cerr << G_STRFUNC << ": Could not get G_FILE_ATTRIBUTE_STANDARD_ICON" << std::endl;
+            }
+            
+          }
         }
       }
     }
+    
+    if(m_pixbuf_original)
+    {
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = get_scaled_image();
+      m_image.set(pixbuf_scaled);
+    }
+    else if(icon)
+    {
+      m_image.set(icon, Gtk::ICON_SIZE_DIALOG);
+    }
+    else
+    {
+      m_image.set(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
+    }
   }
-  //else
-  //  g_warning("ImageGlom::scale(): attempt to scale a null pixbuf.");
+}
+
+Glib::RefPtr<Gdk::Pixbuf> ImageGlom::get_scaled_image()
+{
+  Glib::RefPtr<Gdk::Pixbuf> pixbuf = m_pixbuf_original;
+
+  if(!pixbuf)
+    return pixbuf;
+ 
+  const Gtk::Allocation allocation = m_image.get_allocation();
+  const int pixbuf_height = pixbuf->get_height();
+  const int pixbuf_width = pixbuf->get_width();
+    
+  const int allocation_height = allocation.get_height();
+  const int allocation_width = allocation.get_width();
+      
+  //std::cout << "pixbuf_height=" << pixbuf_height << ", pixbuf_width=" << pixbuf_width << std::endl;
+  //std::cout << "allocation_height=" << allocation.get_height() << ", allocation_width=" << allocation.get_width() << std::endl;
+
+  if( (pixbuf_height > allocation_height) ||
+      (pixbuf_width > allocation_width) )
+  {
+    if(true) //allocation_height > 10 || allocation_width > 10)
+    {
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = Utils::image_scale_keeping_ratio(pixbuf, allocation_height, allocation_width);
+      
+      //Don't set a new pixbuf if the dimensions have not changed:
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf_in_image;
+
+      if(m_image.get_storage_type() == Gtk::IMAGE_PIXBUF) //Prevent warning.
+        pixbuf_in_image = m_image.get_pixbuf();
+
+      if( !pixbuf_in_image || !pixbuf_scaled || (pixbuf_in_image->get_height() != pixbuf_scaled->get_height()) || (pixbuf_in_image->get_width() != pixbuf_scaled->get_width()) )
+      {
+        /*
+        std::cout << "get_scale(): returning scaled" << std::endl;
+        if(pixbuf_scaled)
+        {
+          std::cout << "scaled height=" << pixbuf_scaled->get_height() << ", scaled width=" << pixbuf_scaled->get_width() << std::endl;
+        }
+        */
+        
+        return pixbuf_scaled;
+      }
+      else
+      {
+        //Return the existing one, 
+        //instead of a new one with the same contents,
+        //so no unnecessary changes will be triggered.
+        return pixbuf_in_image;
+      }
+    }
+  }
+  
+  //std::cout << "get_scaled(): returning original" << std::endl;
+  return pixbuf;
 }
 
 void ImageGlom::on_menupopup_activate_open_file()
@@ -334,7 +505,13 @@ void ImageGlom::on_menupopup_activate_open_file_with()
   Application* pApp = get_application();
 
   //Offer the user a choice of suitable applications:
-  Gtk::AppChooserDialog dialog(GLOM_IMAGE_FORMAT_MIME_TYPE);
+  const Glib::ustring mime_type = get_mime_type();
+  if(mime_type.empty())
+  {
+    std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
+  }
+  
+  Gtk::AppChooserDialog dialog(mime_type);
   if(pApp)
     dialog.set_transient_for(*pApp);
 
@@ -350,8 +527,10 @@ void ImageGlom::on_menupopup_activate_open_file_with()
   open_with(app_info);
 }
 
-void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
+Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
 {
+  Glib::ustring uri;
+  
   //Get a temporary file path:
   std::string filepath;
   const int filehandle = Glib::file_open_tmp(filepath);
@@ -360,12 +539,30 @@ void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
   if(filepath.empty())
   {
     std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath" << std::endl;
-    return;
+    return uri;
   }
   
-  const Glib::ustring uri = Glib::filename_to_uri(filepath);
+  uri = Glib::filename_to_uri(filepath);
   
-  if(!save_file(uri))
+  bool saved = false;
+  if(show_progress)
+    saved = save_file(uri);
+  else
+    saved = save_file_sync(uri);
+  
+  if(!saved)
+  {
+    uri = Glib::ustring();
+    std::cerr << G_STRFUNC << ": save_file() failed." << std::endl;
+  }
+
+  return uri;
+}
+
+void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
+{
+  const Glib::ustring uri = save_to_temp_file();
+  if(uri.empty())
     return;
 
   if(app_info)
@@ -402,10 +599,17 @@ static void set_file_filter_images(Gtk::FileChooser& file_chooser)
   filter->add_pixbuf_formats();
   file_chooser.add_filter(filter);
   
+  ev_document_factory_add_filters(GTK_WIDGET(file_chooser.gobj()), 0);
+  
+  //Make Images the currently-selected one:
+  file_chooser.set_filter(filter);
+  
+  /*  ev_document_factory_add_filters() add this already:
   filter = Gtk::FileFilter::create();
   filter->set_name(_("All Files"));
   filter->add_pattern("*");
   file_chooser.add_filter(filter);
+  */
 }
 
 void ImageGlom::on_menupopup_activate_save_file()
@@ -432,6 +636,40 @@ void ImageGlom::on_menupopup_activate_save_file()
   save_file(uri);
 }
 
+bool ImageGlom::save_file_sync(const Glib::ustring& uri)
+{
+  //TODO: We should still do this asynchronously, 
+  //even when we don't use the dialog's run() to do that
+  //because we don't want to offer feedback.
+  //Ideally, EvView would just load from data anyway.
+  
+  const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+  if(!gda_binary)
+  {
+    std::cerr << G_STRFUNC << ": GdaBinary is null" << std::endl;
+    return false;
+  }
+    
+  if(!gda_binary->data)
+  {
+    std::cerr << G_STRFUNC << ": GdaBinary::data is null" << std::endl;
+    return false;
+  }
+
+  try
+  {
+    const std::string filepath = Glib::filename_from_uri(uri);
+    Glib::file_set_contents(filepath, (const char*)gda_binary->data, gda_binary->binary_length);
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << "Exception: " << ex.what() << std::endl;
+    return false;
+  }
+  
+  return true;
+}
+
 bool ImageGlom::save_file(const Glib::ustring& uri)
 {
   DialogImageSaveProgress* dialog_save = 0;
@@ -504,8 +742,7 @@ void ImageGlom::on_menupopup_activate_select_file()
           m_original_data.Glib::ValueBase::init(GDA_TYPE_BINARY);
           gda_value_take_binary(m_original_data.gobj(), bin);
 
-          m_pixbuf_original = dialog->get_pixbuf();
-          scale();
+          show_image_data();
           signal_edited().emit();
         }
       }
@@ -520,14 +757,29 @@ void ImageGlom::on_clipboard_get(Gtk::SelectionData& selection_data, guint /* in
 
   const std::string target = selection_data.get_target(); 
 
-  if(target == GLOM_IMAGE_FORMAT_MIME_TYPE)
+  const Glib::ustring mime_type = get_mime_type();
+  if(mime_type.empty())
   {
+    std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
+  }
+  
+  if(target == mime_type)
+  {
+    const GdaBinary* gda_binary = gda_value_get_binary(m_original_data.gobj());
+    if(!gda_binary)
+      return;
+    
+    if(!gda_binary->data)
+      return;
+    
+    selection_data.set(mime_type, 8, gda_binary->data, gda_binary->binary_length);
+
     // This set() override uses an 8-bit text format for the data.
-    selection_data.set_pixbuf(m_pixbuf_clipboard);
+    //selection_data.set_pixbuf(m_pixbuf_clipboard);
   }
   else
   {
-    g_warning("ExampleWindow::on_clipboard_get(): Unexpected clipboard target format.");
+    std::cout << "ExampleWindow::on_clipboard_get(): Unexpected clipboard target format. expected: " << mime_type << std::endl;
   }
 }
 
@@ -552,8 +804,14 @@ void ImageGlom::on_menupopup_activate_copy()
   Glib::RefPtr<Gtk::Clipboard> refClipboard = Gtk::Clipboard::get();
 
   //Targets:
+  const Glib::ustring mime_type = get_mime_type();
+  if(mime_type.empty())
+  {
+    std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
+  }
+  
   std::vector<Gtk::TargetEntry> listTargets;
-  listTargets.push_back( Gtk::TargetEntry(GLOM_IMAGE_FORMAT_MIME_TYPE) );
+  listTargets.push_back( Gtk::TargetEntry(mime_type) );
 
   refClipboard->set( listTargets, sigc::mem_fun(*this, &ImageGlom::on_clipboard_get), sigc::mem_fun(*this, &ImageGlom::on_clipboard_clear) );
 }
@@ -569,7 +827,7 @@ void ImageGlom::on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pix
     m_original_data = Gnome::Gda::Value();
 
     m_pixbuf_original = pixbuf;
-    scale();
+    show_image_data();
 
     signal_edited().emit();
   }
@@ -593,8 +851,8 @@ void ImageGlom::on_menupopup_activate_clear()
   if(m_read_only)
     return;
 
-  m_pixbuf_original.reset();
-  m_image.set(Gtk::Stock::MISSING_IMAGE, Gtk::ICON_SIZE_DIALOG);
+  m_original_data = Gnome::Gda::Value();
+  show_image_data();
   signal_edited().emit();
 }
 
